@@ -25,20 +25,24 @@ from uuid import uuid4
 class QPOP3Server():
     def __init__(self, ip=None, port=None, username=None, password=None, mocking=False, config=''):
         self.auto_disabled = None
-        self.ip = ip or '0.0.0.0'
-        self.port = port or 110
-        self.username = username or "test"
-        self.password = password or "test"
         self.mocking = mocking or ''
         self.random_servers = ['Microsoft Exchange POP3 service is ready']
         self.process = None
         self.uuid = 'honeypotslogger' + '_' + __class__.__name__ + '_' + str(uuid4())[:8]
         self.config = config
+        self.ip = None
+        self.port = None
+        self.username = None
+        self.password = None
         if config:
             self.logs = setup_logger(self.uuid, config)
             set_local_vars(self, config)
         else:
             self.logs = setup_logger(self.uuid, None)
+        self.ip = ip or self.ip or '0.0.0.0'
+        self.port = port or self.port or 110
+        self.username = username or self.username or 'test'
+        self.password = password or self.password or 'test'
         disable_logger(1, tlog)
 
     def pop3_server_main(self):
